==> react-native-ui-xep-0.1.36.tgz: package/src/atoms/input/styles.ts <==
import { StyleSheet } from 'react-native';
import {
  ButtonColors,
  primaryInputVariables,
} from '../../Configurations/ThemeConfig';
export const styles = StyleSheet.create({
  material: {
    borderBottomWidth: 1,
    color: 'white',
    padding: 0,
    textAlign: 'left',
    borderBottomColor: 'white',
    paddingHorizontal: 0,
    marginLeft: 0,
    height: 37,
     fontSize: 12,
    marginTop: 5
    // height: '120%'
    // borderWidth: 2,
    // borderColor: 'blue'
  },
  inputWrapper: { borderBottomColor: 'white', borderBottomWidth: 1 },
  inputWrapperMB: { borderBottomColor: 'black' },
  materialBlack: {
    borderBottomWidth: 0,
    color: 'black',
  },
  textMaterial: {
    color: 'white',
    fontWeight: 'normal',
    fontSize: 17,
  },
  default: {
    // borderBottomWidth: 0,
    borderWidth: 1,
    borderColor: primaryInputVariables.borderColor,
    borderRadius: 5,
    backgroundColor: 'white',
    margin: 0,
    width: '100%',
    color: '#4a4a4a',
    fontSize: primaryInputVariables.FontSizes,
    lineHeight: 18,
  },
  bordered: {
    borderWidth: 1,
    borderColor: 'rgba(228, 228, 228, 0.6)',
    borderRadius: 5,
    backgroundColor: 'white',
    // borderRightWidth: 1,
    // borderRightColor: '#979797',
    // borderBottomWidth: 1,
    // borderBottomColor: '#979797',
    margin: 0,
    width: '100%',
    color: '#4a4a4a',
    // color: '#C4C4C4',
    fontSize: 16,
    lineHeight: 18,
  },

  textDefault: {
    color: 'white',
    marginBottom: 5,
    fontWeight: 'normal',
    fontSize: 17,
  },
  iconDefault: {
    color: 'black',
    justifyContent: 'center',
    fontSize: 25,
  },
  iconWhite: {
    color: 'white',
    justifyContent: 'center',
    fontSize: 25,
  },
  shadow: {
    elevation: 7,
    shadowColor: ButtonColors.buttonShadow,
    shadowOffset: { width: 0, height: 4 },
    shadowOpacity: 0.8,
  },
  itemStyle: {
    marginBottom: 6,
    borderBottomWidth: 0,
  },
  itemStyleMaterial: {
    // marginBottom: 6,
    borderBottomWidth: 0,
    // borderBottomColor: 'white',
    // backgroundColor:'red',
    // width: '96%'
  },
  itemStyleMaterialBlack: {
    marginBottom: 6,
    borderBottomWidth: 0,
    borderBottomColor: 'black',
  },
  inputItemStyle: {
    borderBottomWidth: 0,
  },
});

==> react-native-ui-xep-0.1.39.tgz: package/src/atoms/input/styles.ts <==
import { StyleSheet } from 'react-native';
import {
  ButtonColors,
  primaryInputVariables,
} from '../../Configurations/ThemeConfig';
export const styles = StyleSheet.create({
  material: {
    borderBottomWidth: 0,
    color: 'white',
    padding: 0,
    textAlign: 'left',
    borderBottomColor: 'white',
    paddingHorizontal: 0,
    marginLeft: 0,
    height: 37,
    fontSize: 12,
  },
  inputWrapper: { borderBottomColor: 'white', borderBottomWidth: 1 },
  inputWrapperMB: { borderBottomColor: 'black', borderBottomWidth: 1 },
  materialBlack: {
    borderBottomWidth: 0,
    color: 'black',
  },
  textMaterial: {
    color: 'white',
    fontWeight: 'normal',
    fontSize: 17,
  },
  default: {
    // borderBottomWidth: 0,
    borderWidth: 1,
    borderColor: primaryInputVariables.borderColor,
    borderRadius: 5,
    backgroundColor: 'white',
    margin: 0,
    width: '100%',
    color: '#4a4a4a',
    fontSize: primaryInputVariables.FontSizes,
    lineHeight: 18,
  },
  bordered: {
    borderWidth: 1,
    borderColor: 'rgba(228, 228, 228, 0.6)',
    borderRadius: 5,
    backgroundColor: 'white',
    // borderRightWidth: 1,
    // borderRightColor: '#979797',
    // borderBottomWidth: 1,
    // borderBottomColor: '#979797',
    margin: 0,
    width: '100%',
    color: '#4a4a4a',
    // color: '#C4C4C4',
    fontSize: 16,
    lineHeight: 18,
  },

  textDefault: {
    color: 'white',
    marginBottom: 5,
    fontWeight: 'normal',
    fontSize: 17,
  },
  iconDefault: {
    color: 'black',
    justifyContent: 'center',
    fontSize: 25,
  },
  iconWhite: {
    color: 'white',
    justifyContent: 'center',
    fontSize: 25,
  },
  shadow: {
    elevation: 7,
    shadowColor: ButtonColors.buttonShadow,
    shadowOffset: { width: 0, height: 4 },
    shadowOpacity: 0.8,
  },
  itemStyle: {
    marginBottom: 6,
    borderBottomWidth: 0,
  },
  itemStyleMaterial: {
    marginBottom: 1,
    borderBottomWidth: 0,
    // borderBottomColor: 'white',
    // backgroundColor:'red',
    // width: '96%'
  },
  itemStyleMaterialBlack: {
    marginBottom: 6,
    borderBottomWidth: 0,
    borderBottomColor: 'black',
  },
  inputItemStyle: {
    borderBottomWidth: 0,
  },
});
